@@ -1,10 +1,11 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2014-12-26'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2015-01-10'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use Moose;
+with 'Pod::Weaver::Role::AddTextToSection';
 with 'Pod::Weaver::Role::Section';
 with 'Pod::Weaver::Role::DumpPerinciCmdLineScript';
 
@@ -77,30 +78,7 @@ sub _process_module {
         $found++;
         #$self->log(["generated POD section %s", $1]);
 
-        # convert characters to bytes, which is expected by read_string()
-        $sectcontent = encode('UTF-8', $sectcontent, Encode::FB_CROAK);
-
-        my $elem = Pod::Elemental::Element::Nested->new({
-            command  => 'head1',
-            content  => $sectname,
-            children => Pod::Elemental->read_string($sectcontent)->children,
-        });
-        my $sect = first {
-            $_->can('command') && $_->command eq 'head1' &&
-                uc($_->{content}) eq uc($sectname) }
-            @{ $document->children }, @{ $input->{pod_document}->children };
-        # if existing section exists, append it
-        #$self->log(["sect=%s", $sect]);
-        if ($sect) {
-            # sometimes we get a Pod::Elemental::Element::Pod5::Command (e.g.
-            # empty "=head1 DESCRIPTION") instead of a
-            # Pod::Elemental::Element::Nested. in that case, just ignore it.
-            if ($sect->can('children')) {
-                push @{ $sect->children }, @{ $elem->children };
-            }
-        } else {
-            push @{ $document->children }, $elem;
-        }
+        $self->add_text_to_section($document, $sectcontent, $sectname);
     }
     if ($found) {
         $self->log(["added POD sections from Rinci metadata for module '%s'", $filename]);
@@ -410,30 +388,11 @@ sub _process_script {
         $modified++;
     }
 
-    # insert FILES section
-    {
-        my $sect = first {
-            $_->can('command') && $_->command eq 'head1' &&
-                uc($_->{content}) eq uc('FILES') }
-            @{ $document->children }, @{ $input->{pod_document}->children };
-        last if $sect;
-        last unless $cli->{read_config} // 1;
+    # XXX insert FILES section (currently done by PWS::Files::PerinciCmdLine,
+    # should probably be done by us?)
 
-        my @content;
-        my $confname = $cli->{config_filename} // "$prog.conf";
-        my $confdirs = $cli->{config_dirs} // ["/etc", "~"];
-        for (@$confdirs) {
-            push @content, "B<$_/$confname>\n\n";
-        }
-
-        my $elem = Pod::Elemental::Element::Nested->new({
-            command  => 'head1',
-            content  => 'FILES',
-            children => Pod::Elemental->read_string(join '',@content)->children,
-        });
-        push @{ $document->children }, $elem;
-        $modified++;
-    }
+    # XXX insert ENVIRONMENT section (currently done by
+    # PWS::Files::PerinciCmdLine, should probably be done by us?)
 
     if ($modified) {
         $self->log(["added POD sections from Rinci metadata for script '%s'", $filename]);
@@ -489,7 +448,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.26 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2014-12-26.
+This document describes version 0.27 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-01-10.
 
 =head1 SYNOPSIS
 
@@ -602,7 +561,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
